==> JDFLibJ-2.1.5.79-sources.jar: org/cip4/jdflib/extensions/xjdfwalker/jdftoxjdf/WalkResource.java <==
/**
 * The CIP4 Software License, Version 1.0
 *
 * Copyright (c) 2001-2014 The International Cooperation for the Integration of 
 * Processes in  Prepress, Press and Postpress (CIP4).  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        The International Cooperation for the Integration of 
 *        Processes in  Prepress, Press and Postpress (www.cip4.org)"
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of 
 *    Processes in  Prepress, Press and Postpress" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4",
 *    nor may "CIP4" appear in their name, without prior written
 *    permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For
 * details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR
 * THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the The International Cooperation for the Integration 
 * of Processes in Prepress, Press and Postpress and was
 * originally based on software 
 * copyright (c) 1999-2001, Heidelberger Druckmaschinen AG 
 * copyright (c) 1999-2001, Agfa-Gevaert N.V. 
 *  
 * For more information on The International Cooperation for the 
 * Integration of Processes in  Prepress, Press and Postpress , please see
 * <http://www.cip4.org/>.
 *  
 * 
 */
package org.cip4.jdflib.extensions.xjdfwalker.jdftoxjdf;

import org.cip4.jdflib.core.AttributeName;
import org.cip4.jdflib.core.KElement;
import org.cip4.jdflib.resource.JDFResource;

// //////////////////////////////////////////////////////////////////////////////
/**
 * @author Rainer Prosi, Heidelberger Druckmaschinen walker for the various resource sets
 */
public class WalkResource extends WalkJDFElement
{
	/**
	 * 
	 */
	public WalkResource()
	{
		super();
	}

	/**
	 * @param jdf
	 * @param xjdf
	 * @return the created resource
	 */
	@Override
	public KElement walk(final KElement jdf, final KElement xjdf)
	{
		final JDFResource r = (JDFResource) jdf;
		final KElement newResLeaf = super.walk(jdf, xjdf);

		if (newResLeaf != null)
		{
			newResLeaf.removeAttribute(AttributeName.ID);
			moveAttribsToBase(xjdf, newResLeaf);
			removeDeprecatedResourceAttribs(r, newResLeaf);
			removeDeprecatedResourceAttribs(r, xjdf);
		}
		return newResLeaf;
	}

	/**
	 * @param xjdf
	 * @param newResLeaf
	 */
	protected void moveAttribsToBase(final KElement xjdf, final KElement newResLeaf)
	{
		final String localName = xjdf.getLocalName();
		final boolean bRoot = "Intent".equals(localName) || "Parameter".equals(localName) || "Resource".equals(localName);
		for (String attrib : this.jdfToXJDF.resAttribs)
		{
			if (newResLeaf.hasAttribute(attrib))
			{
				if (bRoot)
				{
					xjdf.moveAttribute(attrib, newResLeaf, null, null, null);
				}
				else
				{
					newResLeaf.removeAttribute(attrib);
				}
			}
		}
	}

	/**
	 * @param r
	 * @param newResLeaf
	 */
	private void removeDeprecatedResourceAttribs(final JDFResource r, final KElement newResLeaf)
	{
		newResLeaf.removeAttributes(r.getPartIDKeys());
		newResLeaf.removeAttribute(AttributeName.CLASS);
		newResLeaf.removeAttribute(AttributeName.PARTUSAGE);
		newResLeaf.removeAttribute(AttributeName.LOCKED);
		newResLeaf.removeAttribute(AttributeName.NOOP);
		newResLeaf.removeAttribute(AttributeName.SPAWNSTATUS);
		newResLeaf.removeAttribute(AttributeName.SPAWNIDS);
		newResLeaf.removeAttribute(AttributeName.PARTIDKEYS);
	}

	/**
	 * @see org.cip4.jdflib.elementwalker.BaseWalker#matches(org.cip4.jdflib.core.KElement)
	 * @param toCheck
	 * @return true if it matches
	 */
	@Override
	public boolean matches(final KElement toCheck)
	{
		return toCheck instanceof JDFResource;
	}
}

==> JDFLibJ-2.1.5.86-sources.jar: org/cip4/jdflib/extensions/xjdfwalker/jdftoxjdf/WalkResource.java <==
/**
 * The CIP4 Software License, Version 1.0
 *
 * Copyright (c) 2001-2014 The International Cooperation for the Integration of 
 * Processes in  Prepress, Press and Postpress (CIP4).  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        The International Cooperation for the Integration of 
 *        Processes in  Prepress, Press and Postpress (www.cip4.org)"
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of 
 *    Processes in  Prepress, Press and Postpress" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4",
 *    nor may "CIP4" appear in their name, without prior written
 *    permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For
 * details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR
 * THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the The International Cooperation for the Integration 
 * of Processes in Prepress, Press and Postpress and was
 * originally based on software 
 * copyright (c) 1999-2001, Heidelberger Druckmaschinen AG 
 * copyright (c) 1999-2001, Agfa-Gevaert N.V. 
 *  
 * For more information on The International Cooperation for the 
 * Integration of Processes in  Prepress, Press and Postpress , please see
 * <http://www.cip4.org/>.
 *  
 * 
 */
package org.cip4.jdflib.extensions.xjdfwalker.jdftoxjdf;

import org.cip4.jdflib.core.AttributeName;
import org.cip4.jdflib.core.JDFDoc;
import org.cip4.jdflib.core.KElement;
import org.cip4.jdflib.resource.JDFResource;
import org.cip4.jdflib.resource.JDFResource.EnumResourceClass;

// //////////////////////////////////////////////////////////////////////////////
/**
 * @author Rainer Prosi, Heidelberger Druckmaschinen walker for the various resource sets
 */
public class WalkResource extends WalkJDFElement
{
	/**
	 * 
	 */
	public WalkResource()
	{
		super();
	}

	/**
	 * @param jdf
	 * @param xjdf
	 * @return the created resource
	 */
	@Override
	public KElement walk(final KElement jdf, final KElement xjdf)
	{
		final JDFResource r = (JDFResource) jdf;
		final KElement newResLeaf = super.walk(jdf, xjdf);

		if (newResLeaf != null)
		{
			newResLeaf.removeAttribute(AttributeName.ID);
			moveAttribsToBase(xjdf, newResLeaf);
			removeDeprecatedResourceAttribs(r, newResLeaf);
			removeDeprecatedResourceAttribs(r, xjdf);
		}
		return newResLeaf;
	}

	/**
	 * @param xjdf
	 * @param newResLeaf
	 */
	protected void moveAttribsToBase(final KElement xjdf, final KElement newResLeaf)
	{
		final String localName = xjdf.getLocalName();
		final boolean bRoot = "Intent".equals(localName) || "Parameter".equals(localName) || "Resource".equals(localName);
		for (String attrib : this.jdfToXJDF.resAttribs)
		{
			if (newResLeaf.hasAttribute(attrib))
			{
				if (bRoot)
				{
					xjdf.moveAttribute(attrib, newResLeaf, null, null, null);
				}
				else
				{
					newResLeaf.removeAttribute(attrib);
				}
			}
		}
	}

	/**
	 * @param r
	 * @param newResLeaf
	 */
	private void removeDeprecatedResourceAttribs(final JDFResource r, final KElement newResLeaf)
	{
		newResLeaf.removeAttributes(r.getPartIDKeys());
		newResLeaf.removeAttribute(AttributeName.CLASS);
		newResLeaf.removeAttribute(AttributeName.PARTUSAGE);
		newResLeaf.removeAttribute(AttributeName.LOCKED);
		newResLeaf.removeAttribute(AttributeName.NOOP);
		newResLeaf.removeAttribute(AttributeName.SPAWNSTATUS);
		newResLeaf.removeAttribute(AttributeName.SPAWNIDS);
		newResLeaf.removeAttribute(AttributeName.PARTIDKEYS);
	}

	/**
	 * 
	 *  
	 * @param r
	 * @return
	 */
	protected String getClassName(final JDFResource r)
	{
		if (r == null)
		{
			return null;
		}

		EnumResourceClass resourceClass = r.getResourceClass();
		if (resourceClass == null)
		{
			KElement r2 = new JDFDoc(r.getLocalName()).getRoot();
			if (r2 instanceof JDFResource)
			{
				r2.init();
				resourceClass = ((JDFResource) r2).getResourceClass();
			}
		}
		if (resourceClass == null)
		{
			return "Parameter"; // assume parameter if unknown 3rd party stuff
		}
		String className = "Resource";
		if (resourceClass.equals(EnumResourceClass.Parameter))
		{
			className = resourceClass.getName();
		}
		else if (resourceClass.equals(EnumResourceClass.Intent))
		{
			className = resourceClass.getName();
		}
		else if (resourceClass.equals(EnumResourceClass.PlaceHolder))
		{
			return null;
		}
		return className;
	}

	/**
	 * @see org.cip4.jdflib.elementwalker.BaseWalker#matches(org.cip4.jdflib.core.KElement)
	 * @param toCheck
	 * @return true if it matches
	 */
	@Override
	public boolean matches(final KElement toCheck)
	{
		return toCheck instanceof JDFResource;
	}

	/**
	 * 
	 * @param linkTarget
	 * @return
	 */
	protected boolean isProductResource(final JDFResource linkTarget)
	{
		return EnumResourceClass.Intent.equals(linkTarget.getResourceClass());
	}

}
